@@ -3,9 +3,10 @@
 
 int main(int argc, char *argv[])
 {
-//    QApplication::setOrganizationName("hschmitt");
-//    QApplication::setApplicationName("profile-changer-widget");
-//    QApplication::setApplicationVersion("0.4-5");
+    QApplication::setOrganizationName("hschmitt");
+    QApplication::setApplicationName("profile-changer-widget");
+    QApplication::setApplicationVersion("0.4-5");
+    openlog("pcw",LOG_PID,LOG_USER);
     syslog(LOG_WARNING, "Starting profile-changer-widget");
     // enforce native graphics system for now due to a bug in transparency handling
     // you can remove this line if you only target PR 1.2
@@ -26,7 +27,7 @@ int main(int argc, char *argv[])
     syslog(LOG_WARNING, "profile-changer-widget show");
     w.show();
     syslog(LOG_WARNING, "profile-changer-widget app.exec");
-
-    return app.exec();
+    app.exec();
+    closelog();
 }
 
